/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb;

import java.io.File;
import java.security.Policy;

import org.apache.openejb.config.DeploymentModule;

public final class OpenEJBCoreControllerHandler {

    public static final ThreadLocal<OpenEJBCoreController> OPEN_EJB_CORE_CONTROLLER_THREAD_LOCAL = new InheritableThreadLocal<OpenEJBCoreController>();

    public static final OpenEJBCoreController DEFAULT_OPEN_EJB_CORE_CONTROLLER = new OpenEJBCoreController() {

        @Override
        public Policy getPolicy() {
            return Policy.getPolicy();
        }

        @Override
        public AppModuleCreatorData createAppModule(File jarFile) {
            return null;
        }

        @Override
        public WebModuleCreatorData createWebModule(File warFile) {
            return null;
        }

        @Override
        public Class<? extends DeploymentModule> getModuleClass(File jarFile) {
            return null;
        }

        @Override
        public String removeExtension(String name) {
            return null;
        }

    };

    private OpenEJBCoreControllerHandler() {
    }

    public static void setOpenEJBCoreController(final OpenEJBCoreController tomcatController) {
        OPEN_EJB_CORE_CONTROLLER_THREAD_LOCAL.set(tomcatController);
    }

    public static OpenEJBCoreController getOpenEJBCoreController() {
        OpenEJBCoreController tomcatController = OPEN_EJB_CORE_CONTROLLER_THREAD_LOCAL.get();
        if (tomcatController == null) {
            return DEFAULT_OPEN_EJB_CORE_CONTROLLER;
        }
        return tomcatController;
    }
}
